@@ -165,8 +165,8 @@ class AccessAnalyzerClient(BaseClient):
         analyzerName: str,
         type: TypeType,
         archiveRules: Sequence[InlineArchiveRuleTypeDef] = ...,
-        clientToken: str = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        clientToken: str = ...
     ) -> CreateAnalyzerResponseTypeDef:
         """
         Creates an analyzer for your account.
@@ -179,8 +179,8 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerName: str,
-        filter: Mapping[str, CriterionTypeDef],
         ruleName: str,
+        filter: Mapping[str, CriterionTypeDef],
         clientToken: str = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
@@ -290,8 +290,8 @@ class AccessAnalyzerClient(BaseClient):
         accessPreviewId: str,
         analyzerArn: str,
         filter: Mapping[str, CriterionTypeDef] = ...,
-        maxResults: int = ...,
-        nextToken: str = ...
+        nextToken: str = ...,
+        maxResults: int = ...
     ) -> ListAccessPreviewFindingsResponseTypeDef:
         """
         Retrieves a list of access preview findings generated by the specified access
@@ -302,7 +302,7 @@ class AccessAnalyzerClient(BaseClient):
         """
 
     def list_access_previews(
-        self, *, analyzerArn: str, maxResults: int = ..., nextToken: str = ...
+        self, *, analyzerArn: str, nextToken: str = ..., maxResults: int = ...
     ) -> ListAccessPreviewsResponseTypeDef:
         """
         Retrieves a list of access previews for the specified analyzer.
@@ -315,9 +315,9 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerArn: str,
-        maxResults: int = ...,
+        resourceType: ResourceTypeType = ...,
         nextToken: str = ...,
-        resourceType: ResourceTypeType = ...
+        maxResults: int = ...
     ) -> ListAnalyzedResourcesResponseTypeDef:
         """
         Retrieves a list of resources of the specified type that have been analyzed by
@@ -328,7 +328,7 @@ class AccessAnalyzerClient(BaseClient):
         """
 
     def list_analyzers(
-        self, *, maxResults: int = ..., nextToken: str = ..., type: TypeType = ...
+        self, *, nextToken: str = ..., maxResults: int = ..., type: TypeType = ...
     ) -> ListAnalyzersResponseTypeDef:
         """
         Retrieves a list of analyzers.
@@ -338,7 +338,7 @@ class AccessAnalyzerClient(BaseClient):
         """
 
     def list_archive_rules(
-        self, *, analyzerName: str, maxResults: int = ..., nextToken: str = ...
+        self, *, analyzerName: str, nextToken: str = ..., maxResults: int = ...
     ) -> ListArchiveRulesResponseTypeDef:
         """
         Retrieves a list of archive rules created for the specified analyzer.
@@ -352,9 +352,9 @@ class AccessAnalyzerClient(BaseClient):
         *,
         analyzerArn: str,
         filter: Mapping[str, CriterionTypeDef] = ...,
-        maxResults: int = ...,
+        sort: SortCriteriaTypeDef = ...,
         nextToken: str = ...,
-        sort: SortCriteriaTypeDef = ...
+        maxResults: int = ...
     ) -> ListFindingsResponseTypeDef:
         """
         Retrieves a list of findings generated by the specified analyzer.
@@ -364,7 +364,7 @@ class AccessAnalyzerClient(BaseClient):
         """
 
     def list_policy_generations(
-        self, *, maxResults: int = ..., nextToken: str = ..., principalArn: str = ...
+        self, *, principalArn: str = ..., maxResults: int = ..., nextToken: str = ...
     ) -> ListPolicyGenerationsResponseTypeDef:
         """
         Lists all of the policy generations requested in the last seven days.
@@ -385,8 +385,8 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         policyGenerationDetails: PolicyGenerationDetailsTypeDef,
-        clientToken: str = ...,
-        cloudTrailDetails: CloudTrailDetailsTypeDef = ...
+        cloudTrailDetails: CloudTrailDetailsTypeDef = ...,
+        clientToken: str = ...
     ) -> StartPolicyGenerationResponseTypeDef:
         """
         Starts the policy generation request.
@@ -425,8 +425,8 @@ class AccessAnalyzerClient(BaseClient):
         self,
         *,
         analyzerName: str,
-        filter: Mapping[str, CriterionTypeDef],
         ruleName: str,
+        filter: Mapping[str, CriterionTypeDef],
         clientToken: str = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
@@ -441,9 +441,9 @@ class AccessAnalyzerClient(BaseClient):
         *,
         analyzerArn: str,
         status: FindingStatusUpdateType,
-        clientToken: str = ...,
         ids: Sequence[str] = ...,
-        resourceArn: str = ...
+        resourceArn: str = ...,
+        clientToken: str = ...
     ) -> EmptyResponseMetadataTypeDef:
         """
         Updates the status for the specified findings.
